(* :Title: AnalogCircuits *)

(* :Context: TechPackages`AnalogCircuits` *)

(* :Author: John D. DeCocq *)

(* :Summary:
This Package, and its associated palette, CircuitComponents.nb, 
  provide a way to diagram analog circuits in Mathematica 3.0. 
*)

(* :Copyright: None*)

(* :Package Version: 0.5 Alpha *)

(* :Mathematica Version: 3.0 *)

(*Limitations:
		This Package currently only contains analog circuit elements. 
		Most of the major elements of analog circuits are included. 
		Depending on the size of the rendered diagram, 
  some of the component labels may to clipped to allow all components to 
    show. Resizing the diagram to make it larger usually resolves this.
*)

(* :Sources: 
*)

(* :History: 
Developed March 1997 as an internal demonstration.
New components added April 1997.
*)

(* :Future Plans:
Will add variablilty as an option on Resistors, Capacitors and Inductors.
Add an option to set the type size on the labels of various components to 
    allow smaller diagrams to be labeled.
*)

(* Set up contexts and provide usage statements*)
*)
BeginPackage["TechPackages`AnalogCircuits`"]
CornerUpperLeft::usage=
  "CornerUpperLeft places a corner with leads to the right and down into the \
diagram matrix at the current cursor position."

CornerUpperRight::usage=
  "CornerUpperRight places a corner with leads to the left and down into the \
diagram matrix at the current cursor position."

CornerLowerLeft::usage=
  "CornerLowerLeft places a corner with leads to the right and up into the \
diagram matrix at the current cursor position."

CornerLowerRight::usage=
  "CornerLowerRight places a corner with leads to the left and up into the \
diagram matrix at the current cursor position."

WireHorizontal::usage=
  "WireHorizontal places a wire with leads to the left and right into the \
diagram matrix at the current cursor position."

WireVertical::usage=
  "WireVertical places a wire with leads up and down into the diagram matrix \
at the current cursor position."

NodeFourWay::usage=
  "NodeFourWay places a node with leads to the left, right, up and down into \
the diagram matrix at the current cursor position."

NodeTUp::usage=
  "NodeTUp places a node with leads to the left, right and up into the \
diagram matrix at the current cursor position."

NodeTDown::usage=
  "NodeTDown places a node with leads to the left, right and down into the \
diagram matrix at the current cursor position."

NodeTRight::usage=
  "NodeTRight places a node with leads to the right, up and down into the \
diagram matrix at the current cursor position."

NodeTLeft::usage=
  "NodeTLeft places a node with leads to the left, up and down into the \
diagram matrix at the current cursor position."

Ground::usage=
  "Ground places a ground with a single lead up into the diagram matrix at \
the current cursor position."
		
SemiconductorDiodeHorizontal::usage=
  "SemiconductorDiodeHorizontal places a semi-conductor diode with leads to \
the left and right into the diagram matrix at the current cursor position."

SemiconductorDiodeVertical::usage=
  "SemiconductorDiodeVertical places a semi-conductor diode with leads up and \
down into the diagram matrix at the current cursor position."

SPSTSwitchHorizontal::usage=
  "SPSTSwitchHorizontal places a single pole, single throw switch with leads \
to the left and right into the diagram matrix at the current cursor \
position."

SPSTSwitchVertical::usage=
  "SPSTSwitchVertical places a single pole, single throw switch with leads up \
and down into the diagram matrix at the current cursor position."	

SPDTSwitchHorizontal::usage=
  "SPDTSwitchHorizontal places a single pole, double throw switch with leads \
to the left and right into the diagram matrix at the current cursor \
position."

SPDTSwitchVertical::usage=
  "SPDTSwitchVertical places a single pole, double throw switch with leads up \
and down into the diagram matrix at the current cursor position."

AmmeterHorizontal::usage=
  "AmmeterHorizontal places an ammeter with leads to the left and right into \
the diagram matrix at the current cursor position."

AmmeterVertical::usage=
  "AmmeterVertical places an ammeter with leads up and down into the diagram \
matrix at the current cursor position."
		
VoltmeterHorizontal::usage=
  "VoltmeterHorizontal places a voltmeter with leads to the left and right \
into the diagram matrix at the current cursor position."

VoltmeterVertical::usage=
  "VoltmeterVertical places a voltmeter with leads up and down into the \
diagram matrix at the current cursor position."
		
GalvanometerHorizontal::usage=
  "GalvanometerHorizontal places a galovnometer with leads to the left and \
right into the diagram matrix at the current cursor position."

GalvonometerVertical::usage=
  "GalvonometerVertical places a voltmeter with leads up and down into the \
diagram matrix at the current cursor position."
		
NPNTransistor::usage=
  "NPNTransistor places an NPN type transistor into the diagram matrix at the \
current cursor position."
		
PNPTransistor::usage=
  "PNPTransistor places a PNP type transistor into the diagram matrix at the \
current cursor position."
		
ResistorHorizontal::usage=
  "ResistorHorizontal[resistance] places a resistor of the supplied value \
into the diagram matrix at the current cursor position. The resistor will \
have leads to the left and right.
		ResistorHoriztontal[resistance,unit] will modify the units in the label \
from the default value of Ohms, \[CapitalOmega]."
		
ResistorVertical::usage=
  "ResistorVertical[resistance] places a resistor of the supplied value into \
the diagram matrix at the current cursor position. The resistor will have \
leads up and down.
		ResistorVertical[resistance,unit] will modify the units in the label from \
the default value of Ohms, \[CapitalOmega]."
		
CapacitorHorizontal::usage=
  "CapacitorHorizontal[capcatance] places a capacator of the supplied value \
into the diagram matrix at the current cursor position. The capacator will \
have leads to the left and right.
		CapacitorHoriztontal[capcatance,unit] will modify the units in the label \
from the default value of microFarads, \[Mu]F."
		
CapacitorVertical::usage=
  "CapacitorVertical[capcatance] places a capacator of the supplied value \
into the diagram matrix at the current cursor position. The capacator will \
have leads up and down.
		CapacitorVertical[capcatance,unit] will modify the units in the label from \
the default value of microFarads, \[Mu]F."
		
InductorHorizontal::usage=
  "InductorHorizontal[inductance] places a inductor of the supplied value \
into the diagram matrix at the current cursor position. The inductor will \
have leads to the left and right.
		InductorHoriztontal[inductance,unit] will modify the units in the label \
from the default value of milliHenrys, mH."
		
InductorVertical::usage=
  "InductorVertical[inductance] places a inductor of the supplied value into \
the diagram matrix at the current cursor position. The inductor will have \
leads up and down.
		InductorVertical[inductance,unit] will modify the units in the label from \
the default value of milliHenrys, mH."
		
DCSourceHorizontal::usage=
  "DCSourceHorizontal[voltage] places a direct current voltage source of the \
supplied value into the diagram matrix at the current cursor position. The \
voltage source will have leads to the left and right.
		DCSourceHoriztontal[voltage,unit] will modify the units in the label from \
the default value of Volts, V."
		
DCSourceVertical::usage=
  "DCSourceVertical[voltage] places a direct current voltage source of the \
supplied value into the diagram matrix at the current cursor position. The \
voltage source will have leads up and down.
		DCSourceVertical[voltage,unit] will modify the units in the label from the \
default value of Volts, V."
		
ACSourceHorizontal::usage=
  "ACSourceHorizontal[voltage] places an alternating current voltage source \
of the supplied value into the diagram matrix at the current cursor position. \
The voltage source will have leads to the left and right.
		ACSourceHoriztontal[voltage,unit] will modify the units in the label from \
the default value of Volts, V."
		
ACSourceVertical::usage=
  "ACSourceVertical[voltage] places an alternating current voltage source of \
the supplied value into the diagram matrix at the current cursor position. \
The voltage source will have leads up and down.
		ACSourceVertical[voltage,unit] will modify the units in the label from the \
default value of Volts, V."
		
MakeDiagram::usage=
  "MakeDiagram[matrix] creates a GraphicsArray from a matrix of curcuit \
elements contained in this package."

Begin["`Private`"]
MakeDiagram[circuit_] :=
  Show[GraphicsArray[circuit,GraphicsSpacing\[Rule]-.1] ]

NotebookOpen["AddOns\\ExtraPackages\\TechPackages\\CircuitComponents.nb"]
(*
\[SkeletonIndicator]NotebookObject\[SkeletonIndicator]
*)
CornerUpperLeft = 
		Graphics[
			{Line[{{.5,0},{.5,.5},{1,.5}} ],RGBColor[1,1,1],
      Line[{{0,.5},{.5,.5},{.5,1}}]},AspectRatio\[Rule] 1 ]
CornerUpperRight = 
  Graphics[{Line[{{0,.5},{.5,.5},{.5,0}}],RGBColor[1,1,1],
      Line[{{.5,1},{.5,.5},{1,.5}}] },AspectRatio\[Rule] 1 ]
CornerLowerRight = 
  Graphics[{Line[{{.5,1},{.5,.5},{0,.5}}],RGBColor[1,1,1],
      Line[{{.5,0},{.5,.5},{1,.5}} ]} ,AspectRatio\[Rule] 1 ]
CornerLowerLeft =
  Graphics[{Line[{{.5,1},{.5,.5},{1,.5}}],RGBColor[1,1,1],
      Line[{{0,.5},{.5,.5},{.5,0}}]} ,AspectRatio\[Rule] 1 ]
NodeFourWay = 
  Graphics[{Disk[{.5,.5}, .05],Line[{{.5,1},{.5,.55}}] ,
      Line[{{0,.5},{.45,.5}}],Line[{{.5,0},{.5,.45}}],
      Line[{{1,.5},{.55,.5}}]},AspectRatio\[Rule] 1 ]
NodeTDown = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Disk[{.5,.5}, .05],Line[{{0,.5},{.45,.5}}],
      Line[{{.5,0},{.5,.45}}],Line[{{1,.5},{.55,.5}}]},AspectRatio\[Rule] 1 ]
NodeTRight =
  Graphics[{Disk[{.5,.5}, .05],Line[{{.5,1},{.5,.55}}] ,RGBColor[1,1,1],
      Line[{{0,.5},{.45,.5}}],RGBColor[0,0,0],Line[{{.5,0},{.5,.45}}],
      Line[{{1,.5},{.55,.5}}]},AspectRatio\[Rule] 1 ]
NodeTLeft = 
  Graphics[{Disk[{.5,.5}, .05],Line[{{.5,1},{.5,.55}}] ,
      Line[{{0,.5},{.45,.5}}],Line[{{.5,0},{.5,.45}}],RGBColor[1,1,1],
      Line[{{1,.5},{.55,.5}}]},AspectRatio\[Rule] 1 ]
NodeTUp = 
  Graphics[{Disk[{.5,.5}, .05],Line[{{.5,1},{.5,.55}}] ,
      Line[{{0,.5},{.45,.5}}],Line[{{1,.5},{.55,.5}}],RGBColor[1,1,1],
      Line[{{.5,0},{.5,.45}}]},AspectRatio\[Rule] 1 ]
ResistorHorizontal[resistance_,unit_String:"\[CapitalOmega]"] =
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0], Text[resistance unit,{.5,.8}],
      Line[{{0,.5},{.2,.5},{.25,.4},{.35,.6},{.45,.4},{.55,.6},{.65,.4},{.75,.\
6},{.8,.5},{1,.5}}]},AspectRatio\[Rule]1 ]
ResistorVertical[resistance_,unit_String:"\[CapitalOmega]"] =
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0], Text[resistance unit,{.7,.9}],
      Line[{{.5,
            0},{.5,.2},{.4,.25},{.6,.35},{.4,.45},{.6,.55},{.4,.65},{.6,.75},{\
.5,.8},{.5,1}}]},AspectRatio\[Rule]1 ]
CapacitorVertical[capacatance_,unit_String:"\[Mu]F"] = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Text[capacatance unit,{.7,.9}],Line[{{.5,0},{.5, .45}}],
      Line[{{.5,.55},{.5,1}}],Thickness[.02],Line[{{.2,.45},{.8,.45}}],
      Line[{{.2,.55},{.8,.55}}] }  ,AspectRatio\[Rule]1]
CapacitorHorizontal[capacatance_,unit_String:"\[Mu]F"] = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Text[capacatance unit,{.5,.9}],Line[{{0,.5},{.45,.5}}],
      Line[{{.55,.5},{1,.5}}],Thickness[.02],Line[{{.45,.2},{.45,.8}}],
      Line[{{.55,.2},{.55,.8}}] } ,AspectRatio\[Rule]1 ]
InductorHorizontal[inductance_,unit_String:"mH"] =
	Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],RGBColor[0,0,0],
      Text[inductance unit,{.5,.9}],Line[{{0,.5},{.1,.5}}],
      Line[{{.75,.5},{1,.5}}],Circle[{.2,.5},.1,{-9Pi/40,Pi}],
      Circle[{.35,.5},.1,{-9Pi/40,49Pi/40}],
      Circle[{.5,.5},.1,{-9Pi/40,49Pi/40}],Circle[{.65,.5},.1,{0,49Pi/40}] },
    AspectRatio->1]
InductorVertical[inductance_,unit_String:"mH"] = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Text[inductance unit,{.7,.9}],Line[{{.5,0},{.5,.1}}],
      Line[{{.5,.75},{.5,1}}],Circle[{.5,.2},.1,{-Pi/2,29Pi/40}],
      Circle[{.5,.35},.1,{-29Pi/40,29Pi/40}],
      Circle[{.5,.5},.1,{-29Pi/40,29Pi/40}],
      Circle[{.5,.65},.1,{-29Pi/40,Pi/2}](*,RGBColor[1,1,1],
        Polygon[{{.5,.095},{.433,.2},{.433,
              1},{.433,.65},{.5,.75},{.5,.751},{.49,.76},{.39,.753},{.39,.1},{\
.443,.1}}]*) },AspectRatio->1]
SPSTSwitchHorizontal = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{.3,.5}}],Line[{{.3,.5},{.55,.7}}], 
      Line[{{.66,.5},{1,.5}}]   },AspectRatio->1]
SPSTSwitchVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,.3}}],Line[{{.5,.3},{.7,.55}}], 
      Line[{{.5,.66},{.5,1}}]   },AspectRatio->1]
SPDTSwitchHorizontal = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{.3,.5}}],Line[{{.5,.5},{.6,.7}}], 
      Line[{{.66,.5},{1,.5}}]   },AspectRatio->1]
SPDTSwitchVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,.3}}],Line[{{.5,.5},{.7,.6}}], 
      Line[{{.5,.66},{.5,1}}]   },AspectRatio->1]
SemiconductorDiodeHorizontal = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{1,.5}}],Thickness[.02],
      Line[{{.6,.6},{.6,.4}}],Polygon[{{.6,.5},{.4,.4},{.4,.6},{.6,.5}}]},
    AspectRatio\[Rule]1]
SemiconductorDiodeVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,1}}],Thickness[.02],
      Line[{{.6,.6},{.4,.6}}],Polygon[{{.5,.6},{.4,.4},{.6,.4},{.5,.6}}]},
    AspectRatio\[Rule]1]
AmmeterHorizontal = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{.3,.5}}],Line[{{.7,.5},{1,.5}}],
      Thickness[.02],Circle[{.5,.5},.2],Line[{{.4,.43},{.5,.63},{.6,.43}}],
      Line[{{.45,.52},{.55,.52}}]},AspectRatio\[Rule]1]
AmmeterVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,.3}}],Line[{{.5,.7},{.5,1}}],
      Thickness[.02],Circle[{.5,.5},.2],Line[{{.4,.43},{.5,.63},{.6,.43}}],
      Line[{{.45,.52},{.55,.52}}]},AspectRatio\[Rule]1]
VoltmeterHorizontal = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{.3,.5}}],Line[{{.7,.5},{1,.5}}],
      Thickness[.02],Circle[{.5,.5},.2],Line[{{.4,.6},{.5,.4},{.6,.6}}]},
    AspectRatio\[Rule]1]
VoltmeterVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,.3}}],Line[{{.5,.7},{.5,1}}],
      Thickness[.02],Circle[{.5,.5},.2],Line[{{.4,.6},{.5,.4},{.6,.6}}]}
,AspectRatio\[Rule]1]
GalvanometerHorizontal= 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{.3,.5}}],Line[{{.7,.5},{1,.5}}],
      Thickness[.02],Circle[{.5,.5},.2],Circle[{.5,.5},.1],
      Line[{{.55,.48},{.59,.48}}],RGBColor[1,1,1],
      Polygon[{{.5,.49},{.62,.49},{.62,.55},{.5,.55},{.59,.5}}]},
    AspectRatio\[Rule]1]
GalvonometerVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,.3}}],Line[{{.5,.7},{.5,1}}],
      Thickness[.02],Circle[{.5,.5},.2],Circle[{.5,.5},.1],
      Line[{{.55,.48},{.59,.48}}],RGBColor[1,1,1],
      Polygon[{{.5,.49},{.62,.49},{.62,.55},{.5,.55},{.59,.5}}]},
    AspectRatio\[Rule]1]
DCSourceHorizontal[voltage_,unit_String:"V"] = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{1,.5}}],Thickness[.02],
      Line[{{.7,.7},{.7,.3}}],Line[{{.65,.6},{.65,.4}}],
      Line[{{.6,.7},{.6,.3}}],Line[{{.55,.6},{.55,.4}}] , 
      Line[{{.4,.6},{.45,.6}}] ,Line[{{.8,.6},{.85,.6}}],
      Line[{{.825,.57},{.825,.63}}],Text[voltage unit,{.5,.9}]   },
    AspectRatio\[Rule]1]
DCSourceVertical[voltage_,unit_String:"V"] = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,1}}],Thickness[.02],
      Line[{{.7,.7},{.3,.7}}],Line[{{.6,.65},{.4,.65}}],
      Line[{{.7,.6},{.3,.6}}],Line[{{.6,.55},{.4,.55}}] , 
      Line[{{.6,.4},{.65,.4}}] ,Line[{{.6,.8},{.6,.85}}],
      Line[{{.575,.825},{.625,.825}}],Text[voltage unit,{ .2,.9}]  },
    AspectRatio\[Rule]1]
ACSourceHorizontal[voltage_,unit_String:"V"]= 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{.4,.5}}],Line[{{.8,.5},{1,.5}}],
      Thickness[.02],Circle[{.6,.5},.2], Line[{{.3,.6},{.35,.6}}] ,
      Line[{{.85,.6},{.90,.6}}],Line[{{.875,.57},{.875,.63}}],
      Circle[{.55,.5},.05,{0,Pi}],Circle[{.65,.5},.05,{Pi,2Pi}],
      Text[voltage unit,{.5,.9}]  },AspectRatio\[Rule]1]
ACSourceVertical[voltage_,unit_String:"V"]= 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,.4}}],Line[{{.5,.8},{.5,1}}],
      Thickness[.02],Circle[{.5,.6},.2], Line[{{.575,.3},{.625,.3}}] ,
      Line[{{.6,.85},{.6,.9}}],Line[{{.575,.875},{.625,.875}}],
      Circle[{.45,.6},.05,{0,Pi}],Circle[{.55,.6},.05,{Pi,2Pi}],
      Text[voltage unit,{.2,.9}]   },AspectRatio\[Rule]1]
NPNTransistor = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Circle[{.4,.5},.2], Line[{{0,.5},{.25,.5}}],
      Line[{{.25,.45},{.5,.33}}],Polygon[{{.5,.33},{.35,.37},{.38,.42}}],
      Line[{{.5,.33},{.5,0}}],Line[{{.25,.55},{.5,.67}}] ,
      Line[{{.5,.67},{.75,.67},{.9,.5},{1,.5}}],Thickness[.02],
      Line[{{.25,.6},{.25,.4}}] },AspectRatio->1]
PNPTransistor =
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Circle[{.4,.5},.2], Line[{{0,.5},{.25,.5}}],
      Line[{{.25,.45},{.5,.33}}],Polygon[{{.25,.45},{.35,.37},{.38,.42}}],
      Line[{{.5,.33},{.5,0}}],Line[{{.25,.55},{.5,.67}}] ,
      Line[{{.5,.67},{.75,.67},{.9,.5},{1,.5}}],Thickness[.02],
      Line[{{.25,.6},{.25,.4}}] },AspectRatio->1]
Ground =Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,.7},{.5,1}}],Thickness[.02],
      Line[{{.7,.7},{.3,.7}}],Line[{{.65,.65},{.35,.65}}],
      Line[{{.6,.6},{.4,.6}}],Line[{{.55,.55},{.45,.55}}]  },
    AspectRatio\[Rule]1]
(*
\[SkeletonIndicator]Graphics\[SkeletonIndicator]
*)
WireHorizontal = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{0,.5},{1,.5}}]},AspectRatio\[Rule]1]
WireVertical = 
  Graphics[{RGBColor[1,1,1],Polygon[{{0,0},{0,1},{1,1},{1,0}}],
      RGBColor[0,0,0],Line[{{.5,0},{.5,1}}]},AspectRatio\[Rule]1]
End[]
EndPackage[]
(*
(*
	Example Layouts follow
*)
*)
(*
\!\(\*
  RowBox[{"layout1", " ", "=", " ", 
    RowBox[{"(", GridBox[{
          {"CornerUpperLeft", "NPNTransistor", "CornerUpperRight"},
          {\(DCSourceVertical[10]\), \(CapacitorVertical[50]\), 
            \(ResistorVertical[100]\)}
          }], ")"}]}]\)
*)
(*
MakeDiagram[layout1]
*)
(*
\!\(\*
  RowBox[{"layout2", " ", "=", 
    RowBox[{"(", GridBox[{
          {"CornerUpperLeft", \(ACSourceHorizontal[10]\), 
            \(ResistorHorizontal[100, "\<k\[CapitalOmega]\>"]\), 
            "CornerUpperRight"},
          {"NodeTRight", \(ACSourceHorizontal[25]\), "VoltmeterHorizontal", 
            "NodeTLeft"}
          }], ")"}]}]\)
*)
(*
MakeDiagram[layout2]
*)
(*
On[Show::gtype]
*)
(*
\!\(\*
  RowBox[{"layout3", " ", "=", 
    RowBox[{"(", GridBox[{
          {"CornerUpperLeft", 
            \(ResistorHorizontal[100, "\<k\[CapitalOmega]\>"]\), "NodeTDown", 
            \(CapacitorHorizontal[70]\), "CornerUpperRight"},
          {\(ACSourceVertical[10]\), "CornerUpperLeft", "NodeFourWay", 
            "AmmeterHorizontal", "NodeTLeft"},
          {\(InductorVertical[25]\), "CornerLowerLeft", "NodeTUp", 
            "WireHorizontal", "NodeTLeft"},
          {"NodeTRight", "NPNTransistor", \(InductorHorizontal[75]\), 
            "CornerUpperRight", "SPSTSwitchVertical"},
          {\(ResistorVertical[150]\), "NodeTRight", 
            \(DCSourceHorizontal[5]\), "NodeTUp", "NodeTLeft"},
          {"Ground", "CornerLowerLeft", "VoltmeterHorizontal", 
            "SPDTSwitchHorizontal", "CornerLowerRight"}
          }], ")"}]}]\)
*)
(*
MakeDiagram[layout3]
*)
